@@ -1,11 +1,11 @@
 package Test::Kit;
-$Test::Kit::VERSION = '2.01';
+$Test::Kit::VERSION = '2.02';
 use strict;
 use warnings;
 
 use namespace::clean ();
 use Import::Into;
-use Module::Runtime 'use_module';
+use Module::Runtime 'use_module', 'module_notional_filename';
 use Sub::Delete;
 
 use parent 'Exporter';
@@ -93,6 +93,9 @@ sub _create_fake_package {
 
     my $fake_package = "Test::Kit::Fake::$target\::$package";
 
+    my $fake_package_file = module_notional_filename($fake_package);
+    $INC{$fake_package_file} = 1;
+
     my %exclude = map { $_ => 1 } @{ $package_include_hashref->{exclude} || [] };
     my %rename = %{ $package_include_hashref->{rename} || {} };
     my @import = @{ $package_include_hashref->{import} || [] };
